window.Gleam.initSearch([{"doc":"glint","title":"glint","content":"# glint\n\n[![Hex Package](https://img.shields.io/hexpm/v/glint?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glint)\n[![Hex.pm](https://img.shields.io/hexpm/dt/glint?color=ffaff3)](https://hex.pm/packages/glint)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glint/)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tanklesxl/glint/main)](https://github.com/tanklesxl/glint/actions)\n\nGleam command line argument parsing with basic flag support.\n\n## Installation\n\nTo install from hex:\n\n```sh\ngleam add glint\n```\n\n## Usage\n\nYou can import `glint` as a dependency and use it as follows:\n(found in `examples/hello/src/hello.gleam` directory)\n\n```gleam\nimport gleam/io\nimport gleam/map\nimport gleam/string.{join, uppercase}\nimport gleam/erlang.{start_arguments}\nimport glint.{CommandInput}\nimport glint/flag\n\nfn hello(input: CommandInput) {\n  assert Ok(flag.B(caps)) = flag.get_value(from: input.flags, for: &quot;caps&quot;)\n  let to_say = [&quot;Hello,&quot;, ..input.args]\n  case caps {\n    True -&gt;\n      to_say\n      |&gt; join(&quot; &quot;)\n      |&gt; uppercase()\n\n    False -&gt; join(to_say, &quot; &quot;)\n  }\n  |&gt; string.append(&quot;!&quot;)\n  |&gt; io.println()\n}\n\npub fn main() {\n  glint.new()\n  |&gt; glint.add_command(\n    at: [],\n    do: hello,\n    with: [flag.bool(&quot;caps&quot;, False, &quot;Capitalize the provided name&quot;)],\n    described: &quot;Prints Hello, &lt;NAME&gt;!&quot;,\n    used: &quot;&#39;gleam run &lt;NAME&gt;&#39; or &#39;gleam run &lt;NAME&gt; --caps&#39;&quot;,\n  )\n  |&gt; glint.run(start_arguments())\n}\n\n```\n\nRun it with either of:\n\n- `gleam run Bob`, `gleam run -- --caps=false Bob`, or `gleam run Bob --caps=false`  which will print `Hello, Bob!`\n- `gleam run -- --caps Bob` or  `gleam run -- --caps=true Bob`, or `gleam run Bob --caps` which will print `HELLO, BOB!`\n\n### Built-In Help messages\n\nRun `gleam run -- --help` to print the generated help message, which in this case will look like:\n\n```text\nPrints Hello, &lt;NAME&gt;!\n\nUSAGE:\n        &#39;gleam run &lt;NAME&gt;&#39; or &#39;gleam run &lt;NAME&gt; --caps&#39;\n\nFLAGS:\n        --help                  Print help information\n        --caps=&lt;CAPS&gt;           Capitalize the provided name\n```\n\n*Note*: Due to [this issue](https://github.com/gleam-lang/gleam/issues/1457) commands with flags immediately after `gleam run` must include the `--` as shown above\n","url":"index.html"},{"doc":"glint/flag/constraint","title":"Constraint","content":"pub type Constraint(a) =\n  fn(a) -&gt; Result(Nil)\n Constraint type for verifying flag values\n\n\nSynonyms:\nglint/flag/constraint.Constraint\nglint/flag/constraint Constraint","url":"glint/flag/constraint.html#Constraint"},{"doc":"glint/flag/constraint","title":"each","content":"pub fn each(constraint: fn(a) -&gt; Result(Nil, Snag)) -&gt; fn(List(a)) -&gt;\n  Result(Nil, Snag)\n each is a convenience function for applying a Constraint(a) to a List(a).\n This is useful because the default behaviour for constraints on lists is that they will apply to the list as a whole.\n \n For example, to apply one_of to all items in a `List(Int)`:\n \n [1, 2, 3, 4] |&gt; one_of |&gt; each\n \nSynonyms:\nglint/flag/constraint.each\nglint/flag/constraint each","url":"glint/flag/constraint.html#each"},{"doc":"glint/flag/constraint","title":"none_of","content":"pub fn none_of(disallowed: List(a)) -&gt; fn(a) -&gt; Result(Nil, Snag)\n none_of returns a Constraint that ensures the parsed flag value is not one of the disallowed values.\n\nSynonyms:\nglint/flag/constraint.none_of\nglint/flag/constraint none_of","url":"glint/flag/constraint.html#none_of"},{"doc":"glint/flag/constraint","title":"one_of","content":"pub fn one_of(allowed: List(a)) -&gt; fn(a) -&gt; Result(Nil, Snag)\n one_of returns a Constraint that ensures the parsed flag value is\n one of the allowed values.\n\nSynonyms:\nglint/flag/constraint.one_of\nglint/flag/constraint one_of","url":"glint/flag/constraint.html#one_of"},{"doc":"glint/flag/constraint","title":"glint/flag/constraint","content":"","url":"glint/flag/constraint.html"},{"doc":"glint/flag","title":"Contents","content":"pub type Contents {\n  Contents(value: Value, description: Description)\n}\n Flag data and descriptions\n\nContents(value: Value, description: Description)\n\n\nSynonyms:\nglint/flag.Contents\nglint/flag Contents","url":"glint/flag.html#Contents"},{"doc":"glint/flag","title":"Description","content":"pub type Description =\n  String\n Flag descriptions\n\n\nSynonyms:\nglint/flag.Description\nglint/flag Description","url":"glint/flag.html#Description"},{"doc":"glint/flag","title":"Flag","content":"pub type Flag =\n  #(String, Contents)\n Associates a name with a flag value\n\n\nSynonyms:\nglint/flag.Flag\nglint/flag Flag","url":"glint/flag.html#Flag"},{"doc":"glint/flag","title":"FlagOpt","content":"pub type FlagOpt(a) {\n  WithDefault(a)\n  WithConstraint(Constraint(a))\n}\n FlagOpt is used for configuring flag creation.\n\nWithDefault(a)\n\n\nWithConstraint(Constraint(a))\n\n\nSynonyms:\nglint/flag.FlagOpt\nglint/flag FlagOpt","url":"glint/flag.html#FlagOpt"},{"doc":"glint/flag","title":"Map","content":"pub type Map =\n  map.Map(String, Contents)\n Associate flag names to their current values.\n\n\nSynonyms:\nglint/flag.Map\nglint/flag Map","url":"glint/flag.html#Map"},{"doc":"glint/flag","title":"Value","content":"pub opaque type Value\n Supported flag types.\n\n\nSynonyms:\nglint/flag.Value\nglint/flag Value","url":"glint/flag.html#Value"},{"doc":"glint/flag","title":"prefix","content":"pub const prefix: String = &quot;--&quot;\n Flag inputs must start with this prefix\n\nSynonyms:\nglint/flag.prefix\nglint/flag prefix","url":"glint/flag.html#prefix"},{"doc":"glint/flag","title":"bool","content":"pub fn bool(called name: String, default value: Option(Bool), explained description: String) -&gt; #(\n  String,\n  Contents,\n)\n Creates a bool flag.\n\nSynonyms:\nglint/flag.bool\nglint/flag bool","url":"glint/flag.html#bool"},{"doc":"glint/flag","title":"build_map","content":"pub fn build_map(flags: List(#(String, Contents))) -&gt; Map(\n  String,\n  Contents,\n)\n Convert a list of flags to a Map.\n\nSynonyms:\nglint/flag.build_map\nglint/flag build_map","url":"glint/flag.html#build_map"},{"doc":"glint/flag","title":"flag_type_help","content":"pub fn flag_type_help(flag: #(String, Contents)) -&gt; String\n Generate the help message contents for a single flag\n \nSynonyms:\nglint/flag.flag_type_help\nglint/flag flag_type_help","url":"glint/flag.html#flag_type_help"},{"doc":"glint/flag","title":"flags_help","content":"pub fn flags_help(flags: Map(String, Contents)) -&gt; List(String)\n Generate help messages for all flags\n\nSynonyms:\nglint/flag.flags_help\nglint/flag flags_help","url":"glint/flag.html#flags_help"},{"doc":"glint/flag","title":"float","content":"pub fn float(called name: String, explained description: String, with opts: List(\n    FlagOpt(Float),\n  )) -&gt; #(String, Contents)\n Creates a float flag.\n\nSynonyms:\nglint/flag.float\nglint/flag float","url":"glint/flag.html#float"},{"doc":"glint/flag","title":"floats","content":"pub fn floats(called name: String, explained description: String, with opts: List(\n    FlagOpt(List(Float)),\n  )) -&gt; #(String, Contents)\n Creates a float list flag.\n\nSynonyms:\nglint/flag.floats\nglint/flag floats","url":"glint/flag.html#floats"},{"doc":"glint/flag","title":"get_bool","content":"pub fn get_bool(from flags: Map(String, Contents), for name: String) -&gt; Result(\n  Bool,\n  Snag,\n)\n Gets the current value for the associated bool flag\n\nSynonyms:\nglint/flag.get_bool\nglint/flag get_bool","url":"glint/flag.html#get_bool"},{"doc":"glint/flag","title":"get_bool_value","content":"pub fn get_bool_value(from flag: #(String, Contents)) -&gt; Result(\n  Bool,\n  Snag,\n)\n Gets the current value for the provided bool flag\n\nSynonyms:\nglint/flag.get_bool_value\nglint/flag get_bool_value","url":"glint/flag.html#get_bool_value"},{"doc":"glint/flag","title":"get_float","content":"pub fn get_float(from flags: Map(String, Contents), for name: String) -&gt; Result(\n  Float,\n  Snag,\n)\n Gets the current value for the associated float flag\n\nSynonyms:\nglint/flag.get_float\nglint/flag get_float","url":"glint/flag.html#get_float"},{"doc":"glint/flag","title":"get_float_value","content":"pub fn get_float_value(from flag: #(String, Contents)) -&gt; Result(\n  Float,\n  Snag,\n)\n Gets the current value for the provided float flag\n\nSynonyms:\nglint/flag.get_float_value\nglint/flag get_float_value","url":"glint/flag.html#get_float_value"},{"doc":"glint/flag","title":"get_floats","content":"pub fn get_floats(from flags: Map(String, Contents), for name: String) -&gt; Result(\n  List(Float),\n  Snag,\n)\n Gets the current value for the associated floats flag\n\nSynonyms:\nglint/flag.get_floats\nglint/flag get_floats","url":"glint/flag.html#get_floats"},{"doc":"glint/flag","title":"get_floats_value","content":"pub fn get_floats_value(from flag: #(String, Contents)) -&gt; Result(\n  List(Float),\n  Snag,\n)\n Gets the current value for the provided floats flag\n\nSynonyms:\nglint/flag.get_floats_value\nglint/flag get_floats_value","url":"glint/flag.html#get_floats_value"},{"doc":"glint/flag","title":"get_int","content":"pub fn get_int(from flags: Map(String, Contents), for name: String) -&gt; Result(\n  Int,\n  Snag,\n)\n Gets the current value for the associated int flag\n\nSynonyms:\nglint/flag.get_int\nglint/flag get_int","url":"glint/flag.html#get_int"},{"doc":"glint/flag","title":"get_int_value","content":"pub fn get_int_value(from flag: #(String, Contents)) -&gt; Result(\n  Int,\n  Snag,\n)\n Gets the current value for the provided int flag\n\nSynonyms:\nglint/flag.get_int_value\nglint/flag get_int_value","url":"glint/flag.html#get_int_value"},{"doc":"glint/flag","title":"get_ints","content":"pub fn get_ints(from flags: Map(String, Contents), for name: String) -&gt; Result(\n  List(Int),\n  Snag,\n)\n Gets the current value for the associated ints flag\n\nSynonyms:\nglint/flag.get_ints\nglint/flag get_ints","url":"glint/flag.html#get_ints"},{"doc":"glint/flag","title":"get_ints_value","content":"pub fn get_ints_value(from flag: #(String, Contents)) -&gt; Result(\n  List(Int),\n  Snag,\n)\n Gets the current value for the provided ints flag\n\nSynonyms:\nglint/flag.get_ints_value\nglint/flag get_ints_value","url":"glint/flag.html#get_ints_value"},{"doc":"glint/flag","title":"get_string","content":"pub fn get_string(from flags: Map(String, Contents), for name: String) -&gt; Result(\n  String,\n  Snag,\n)\n Gets the current value for the associated string flag\n\nSynonyms:\nglint/flag.get_string\nglint/flag get_string","url":"glint/flag.html#get_string"},{"doc":"glint/flag","title":"get_string_value","content":"pub fn get_string_value(from flag: #(String, Contents)) -&gt; Result(\n  String,\n  Snag,\n)\n Gets the current value for the provided string flag\n\nSynonyms:\nglint/flag.get_string_value\nglint/flag get_string_value","url":"glint/flag.html#get_string_value"},{"doc":"glint/flag","title":"get_strings","content":"pub fn get_strings(from flags: Map(String, Contents), for name: String) -&gt; Result(\n  List(String),\n  Snag,\n)\n Gets the current value for the associated strings flag\n\nSynonyms:\nglint/flag.get_strings\nglint/flag get_strings","url":"glint/flag.html#get_strings"},{"doc":"glint/flag","title":"get_strings_value","content":"pub fn get_strings_value(from flag: #(String, Contents)) -&gt; Result(\n  List(String),\n  Snag,\n)\n Gets the current value for the provided strings flag\n\nSynonyms:\nglint/flag.get_strings_value\nglint/flag get_strings_value","url":"glint/flag.html#get_strings_value"},{"doc":"glint/flag","title":"int","content":"pub fn int(called name: String, explained description: String, with opts: List(\n    FlagOpt(Int),\n  )) -&gt; #(String, Contents)\n Creates an int flag.\n\nSynonyms:\nglint/flag.int\nglint/flag int","url":"glint/flag.html#int"},{"doc":"glint/flag","title":"ints","content":"pub fn ints(called name: String, explained description: String, with opts: List(\n    FlagOpt(List(Int)),\n  )) -&gt; #(String, Contents)\n Creates an int list flag.\n\nSynonyms:\nglint/flag.ints\nglint/flag ints","url":"glint/flag.html#ints"},{"doc":"glint/flag","title":"string","content":"pub fn string(called name: String, explained description: String, with opts: List(\n    FlagOpt(String),\n  )) -&gt; #(String, Contents)\n Creates a string flag.\n\nSynonyms:\nglint/flag.string\nglint/flag string","url":"glint/flag.html#string"},{"doc":"glint/flag","title":"strings","content":"pub fn strings(called name: String, explained description: String, with opts: List(\n    FlagOpt(List(String)),\n  )) -&gt; #(String, Contents)\n Creates a string list flag.\n\nSynonyms:\nglint/flag.strings\nglint/flag strings","url":"glint/flag.html#strings"},{"doc":"glint/flag","title":"update_flags","content":"pub fn update_flags(in flags: Map(String, Contents), with flag_input: String) -&gt; Result(\n  Map(String, Contents),\n  Snag,\n)\n Updates a flag value, ensuring that the new value can satisfy the required type.\n Assumes that all flag inputs passed in start with --\n This function is only intended to be used from glint.execute_root\n\nSynonyms:\nglint/flag.update_flags\nglint/flag update_flags","url":"glint/flag.html#update_flags"},{"doc":"glint/flag","title":"glint/flag","content":"","url":"glint/flag.html"},{"doc":"glint","title":"CmdResult","content":"pub type CmdResult(a) =\n  Result(Out(a))\n Result type for command execution\n\n\nSynonyms:\nglint.CmdResult\nglint CmdResult","url":"glint.html#CmdResult"},{"doc":"glint","title":"Command","content":"pub opaque type Command(a)\n Command tree representation.\n\n\nSynonyms:\nglint.Command\nglint Command","url":"glint.html#Command"},{"doc":"glint","title":"CommandInput","content":"pub type CommandInput {\n  CommandInput(args: List(String), flags: FlagMap)\n}\n Input type for `Runner`.\n\nCommandInput(args: List(String), flags: FlagMap)\n\n\nSynonyms:\nglint.CommandInput\nglint CommandInput","url":"glint.html#CommandInput"},{"doc":"glint","title":"Config","content":"pub type Config(a) {\n  Config(pretty_help: Option(PrettyHelp))\n}\n Config for glint\n\nConfig(pretty_help: Option(PrettyHelp))\n\n\nSynonyms:\nglint.Config\nglint Config","url":"glint.html#Config"},{"doc":"glint","title":"Contents","content":"pub opaque type Contents(a)\n Command contents\n\n\nSynonyms:\nglint.Contents\nglint Contents","url":"glint.html#Contents"},{"doc":"glint","title":"Glint","content":"pub opaque type Glint(a)\n Glint container type for config and commands\n\n\nSynonyms:\nglint.Glint\nglint Glint","url":"glint.html#Glint"},{"doc":"glint","title":"Out","content":"pub type Out(a) {\n  Out(a)\n  Help(String)\n}\n Ok type for command execution \n\nOut(a)\n Container for the command return value\n\nHelp(String)\n Container for the generated help string\n\nSynonyms:\nglint.Out\nglint Out","url":"glint.html#Out"},{"doc":"glint","title":"PrettyHelp","content":"pub type PrettyHelp {\n  PrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n}\n PrettyHelp defines the header colours to be used when styling help text\n\nPrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n\n\nSynonyms:\nglint.PrettyHelp\nglint PrettyHelp","url":"glint.html#PrettyHelp"},{"doc":"glint","title":"Runner","content":"pub type Runner(a) =\n  fn(CommandInput) -&gt; a\n Function type to be run by `glint`.\n\n\nSynonyms:\nglint.Runner\nglint Runner","url":"glint.html#Runner"},{"doc":"glint","title":"Stub","content":"pub type Stub(a) {\n  Stub(\n    path: List(String),\n    run: Runner(a),\n    flags: List(Flag),\n    description: String,\n  )\n}\n Create command stubs to be used in `add_command_from_stub`\n\nStub(\n  path: List(String),\n  run: Runner(a),\n  flags: List(Flag),\n  description: String,\n)\n\n\nSynonyms:\nglint.Stub\nglint Stub","url":"glint.html#Stub"},{"doc":"glint","title":"default_config","content":"pub const default_config: Config(a) = Config(pretty_help: None)\n Default config\n\nSynonyms:\nglint.default_config\nglint default_config","url":"glint.html#default_config"},{"doc":"glint","title":"add_command","content":"pub fn add_command(to glint: Glint(a), at path: List(String), do f: fn(\n    CommandInput,\n  ) -&gt; a, with flags: List(#(String, Contents)), described description: String) -&gt; Glint(\n  a,\n)\n Adds a new command to be run at the specified path.\n\n If the path is `[]`, the root command is set with the provided function and\n flags.\n\n Note: all command paths are sanitized by stripping whitespace and removing any empty string elements.\n\nSynonyms:\nglint.add_command\nglint add_command","url":"glint.html#add_command"},{"doc":"glint","title":"add_command_from_stub","content":"pub fn add_command_from_stub(to glint: Glint(a), with stub: Stub(\n    a,\n  )) -&gt; Glint(a)\n Add a command to the root given a stub \n\nSynonyms:\nglint.add_command_from_stub\nglint add_command_from_stub","url":"glint.html#add_command_from_stub"},{"doc":"glint","title":"default_pretty_help","content":"pub fn default_pretty_help() -&gt; PrettyHelp\n Default pretty help heading colouring\n mint (r: 182, g: 255, b: 234) colour for usage\n pink (r: 255, g: 175, b: 243) colour for flags\n buttercup (r: 252, g: 226, b: 174) colour for subcommands\n\nSynonyms:\nglint.default_pretty_help\nglint default_pretty_help","url":"glint.html#default_pretty_help"},{"doc":"glint","title":"execute","content":"pub fn execute(glint: Glint(a), args: List(String)) -&gt; Result(\n  Out(a),\n  Snag,\n)\n Determines which command to run and executes it.\n\n Sets any provided flags if necessary.\n\n Each value prefixed with `--` is parsed as a flag.\n\n This function does not print its output and is mainly intended for use within `glint` itself.\n If you would like to print the output of a command please see the `run` function\n in tandem with the`with_print_output` function.\n\nSynonyms:\nglint.execute\nglint execute","url":"glint.html#execute"},{"doc":"glint","title":"help_flag","content":"pub fn help_flag() -&gt; String\n Function to create the help flag string\n Exported for testing purposes only\n\nSynonyms:\nglint.help_flag\nglint help_flag","url":"glint.html#help_flag"},{"doc":"glint","title":"new","content":"pub fn new() -&gt; Glint(a)\n Creates a new command tree.\n\nSynonyms:\nglint.new\nglint new","url":"glint.html#new"},{"doc":"glint","title":"run","content":"pub fn run(from glint: Glint(a), for args: List(String)) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function ignores any value returned by the command that was run.\n If you would like to do something with the command output please see the run_and_handle function.\n\nSynonyms:\nglint.run\nglint run","url":"glint.html#run"},{"doc":"glint","title":"run_and_handle","content":"pub fn run_and_handle(from glint: Glint(a), for args: List(String), with handle: fn(\n    a,\n  ) -&gt; Nil) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function calls the provided handler with the value returned by the command that was run.\n\nSynonyms:\nglint.run_and_handle\nglint run_and_handle","url":"glint.html#run_and_handle"},{"doc":"glint","title":"with_config","content":"pub fn with_config(glint: Glint(a), config: Config(a)) -&gt; Glint(a)\n Add the provided config to the existing command tree\n\nSynonyms:\nglint.with_config\nglint with_config","url":"glint.html#with_config"},{"doc":"glint","title":"with_global_flags","content":"pub fn with_global_flags(glint: Glint(a), flags: List(\n    #(String, Contents),\n  )) -&gt; Glint(a)\n Add global flags to the existing command tree\nSynonyms:\nglint.with_global_flags\nglint with_global_flags","url":"glint.html#with_global_flags"},{"doc":"glint","title":"with_pretty_help","content":"pub fn with_pretty_help(glint: Glint(a), pretty: PrettyHelp) -&gt; Glint(\n  a,\n)\n Enable custom colours for help text headers\n For a pre-made colouring use `default_pretty_help()`\n \nSynonyms:\nglint.with_pretty_help\nglint with_pretty_help","url":"glint.html#with_pretty_help"},{"doc":"glint","title":"without_pretty_help","content":"pub fn without_pretty_help(glint: Glint(a)) -&gt; Glint(a)\n Disable custom colours for help text headers\n \nSynonyms:\nglint.without_pretty_help\nglint without_pretty_help","url":"glint.html#without_pretty_help"},{"doc":"glint","title":"glint","content":"","url":"glint.html"}]);